@@ -1019,8 +1019,4 @@ def context_of(data):
     else:
         return F.context(data)
 
-def dtype_of(data):
-    """Return the dtype of the data which can be either a tensor or a dict of tensors."""
-    return F.dtype(next(iter(data.values())) if isinstance(data, Mapping) else data)
-
 _init_api("dgl.utils.internal")
